@@ -10,7 +10,11 @@
 
 #include "configuration.h"
 
+
 typedef struct {
+	int just_created;
+	const char** wizard_settings;
+	int wizard_mode;
 	GtkWidget* dialog;
 	GtkWidget* edit_button;
 	GtkListStore* list_store;
@@ -55,14 +59,6 @@ static void error_occured(MicrofeedSubscriber* subscriber, const char* publisher
 	}
 }
 
-static void settings_subscribed(MicrofeedSubscriber* subscriber, const char* publisher, const char* uri, const char* uid, const char* error_name, const char* error_message, void* user_data) {
-	if (error_name) {
-		error_occured(subscriber, publisher, uri, uid, error_name, error_message, user_data);
-	} else {
-		microfeed_subscriber_republish_items(subscriber, publisher, uri, NULL, NULL, 1024, error_occured, user_data);	
-	}
-}
-
 static void setting(MicrofeedSubscriber* subscriber, const char* publisher, const char* uri, MicrofeedItem* item, void* user_data) {
 	EditDialog* edit_dialog;
 	const char* uid;
@@ -78,6 +74,7 @@ static void setting(MicrofeedSubscriber* subscriber, const char* publisher, cons
 	edit_dialog = (EditDialog*)user_data;
 	
 	uid = microfeed_item_get_uid(item);
+	
 	if (strcmp(uid, MICROFEED_ITEM_UID_FEED_METADATA) &&
 	    uid[0] != '.') {
 		if (!(text = microfeed_item_get_property(item, "setting.text"))) {
@@ -104,17 +101,20 @@ static void setting(MicrofeedSubscriber* subscriber, const char* publisher, cons
 		search_data->column = 1;
 		search_data->value = uid;
 		gtk_tree_model_foreach(GTK_TREE_MODEL(edit_dialog->list_store), tree_model_search_function, search_data);
-		if (!search_data->found) {
+		if (!search_data->found && !edit_dialog->wizard_mode) {
 			gtk_list_store_append(edit_dialog->list_store, &search_data->iter);
+			search_data->found = 1;
+		}
+		if (search_data->found) {
+			gtk_list_store_set(edit_dialog->list_store, &search_data->iter, 0, value_unit, 1, uid, 2, text, 3, value, 4, unit, 5, type, 6, length, -1);
 		}
-		gtk_list_store_set(edit_dialog->list_store, &search_data->iter, 0, value_unit, 1, uid, 2, text, 3, value, 4, unit, 5, type, 6, length, -1);
 		microfeed_memory_free(search_data);
 		free(value_unit);
 	}
 }
 
 static MicrofeedSubscriberCallbacks callbacks = {
-	error_occured,
+	NULL, /* error_occured */
 	NULL, /* feed_update_started */
 	NULL, /* feed_update_ended */
 	NULL, /* feed_republishing_started */
@@ -127,6 +127,45 @@ static MicrofeedSubscriberCallbacks callbacks = {
 	NULL /* item_data_received */
 };
 
+static void update_list(MicrofeedSubscriber* subscriber, const char* publisher, EditDialog* edit_dialog) {
+	const char** s;
+	const char* space;
+	char* uid;
+	MicrofeedItem* item;
+	GtkTreeIter iter;
+	
+	gtk_list_store_clear(edit_dialog->list_store);
+
+	if (edit_dialog->wizard_settings && edit_dialog->wizard_mode) {
+		for (s = edit_dialog->wizard_settings; *s; s++) {
+			if ((space = strchr(*s, ' '))) {
+	printf("*  %s  %d  *\n", *s, edit_dialog->just_created);
+				if (edit_dialog->just_created) {
+					uid = g_strndup(*s, space - *s);
+					item = microfeed_item_new(uid, time(NULL));
+					microfeed_item_set_property(item, "setting.value", space + 1);
+					free(uid);
+					microfeed_subscriber_modify_item(subscriber, publisher, MICROFEED_FEED_URI_SETTINGS, item, NULL, NULL);
+					microfeed_item_free(item);
+				}
+			} else {
+				gtk_list_store_append(edit_dialog->list_store, &iter);
+				gtk_list_store_set(edit_dialog->list_store, &iter, 1, *s, -1);
+			}
+		}
+	}
+	edit_dialog->just_created = 0;
+	microfeed_subscriber_republish_items(subscriber, publisher, MICROFEED_FEED_URI_SETTINGS, NULL, NULL, 1024, error_occured, edit_dialog);
+}
+
+static void settings_subscribed(MicrofeedSubscriber* subscriber, const char* publisher, const char* uri, const char* uid, const char* error_name, const char* error_message, void* user_data) {
+	if (error_name) {
+		error_occured(subscriber, publisher, uri, uid, error_name, error_message, user_data);
+	} else {
+		update_list(subscriber, publisher, user_data);	
+	}
+}
+
 #if MAEMO_CHANGES
 
 static void on_changed(HildonTouchSelector* touch_selector, gint column, gpointer user_data) {
@@ -144,7 +183,7 @@ static void on_row_activated(GtkTreeView* tree_view, GtkTreePath* path, GtkTreeV
 	EditDialog* edit_dialog;
 	
 	edit_dialog = (EditDialog*)user_data;
-	gtk_dialog_response(GTK_DIALOG(edit_dialog->dialog), 1);
+	gtk_dialog_response(GTK_DIALOG(edit_dialog->dialog), 2);
 }
 
 static void on_selection_changed(GtkTreeSelection* selection, gpointer user_data) {
@@ -153,11 +192,12 @@ static void on_selection_changed(GtkTreeSelection* selection, gpointer user_data
 
 	edit_dialog = (EditDialog*)user_data;
 	selected = gtk_tree_selection_get_selected(selection, NULL, NULL);
+	gtk_widget_set_sensitive(edit_dialog->edit_button, selected);
 }
 
 #endif
 
-void show_edit_dialog(MicrofeedSubscriber* subscriber, GtkWindow* parent, const char* publisher) {
+void show_edit_dialog(MicrofeedSubscriber* subscriber, GtkWindow* parent, const char* publisher, int just_created) {
 	MicrofeedConfiguration* configuration;
 	char* publisher_part;
 	char* provider_part;
@@ -174,9 +214,9 @@ void show_edit_dialog(MicrofeedSubscriber* subscriber, GtkWindow* parent, const
 	GtkWidget* tree_view;
 	GtkTreeViewColumn* column;
 	GtkWidget* scrolled_window;
+	GtkTreeSelection* selection;
 #endif
 	GtkCellRenderer* renderer;
-	GtkTreeSelection* selection;
 	int response;
 	GtkTreeModel* tree_model;
 	GtkTreeIter iter;
@@ -186,18 +226,31 @@ void show_edit_dialog(MicrofeedSubscriber* subscriber, GtkWindow* parent, const
 	GValue unit_value = { 0 };
 	GValue type_value = { 0 };
 	GValue length_value = { 0 };
+	GtkWidget* mode_button;
+	GtkLabel* mode_label;
 	
-	configuration = microfeed_subscriber_get_configuration(subscriber);
+	configuration = microfeed_configuration_new();
 	
-	if ((provider_part = strchr(publisher, ':')) && provider_part != publisher && provider_part[1] != 0) {
+	if ((provider_part = strchr(publisher, MICROFEED_PUBLISHER_IDENTIFIER_SEPARATOR_CHAR)) && provider_part != publisher && provider_part[1] != 0) {
 		publisher_part = strndup(publisher, provider_part - publisher);
 		provider_part = strdup(provider_part + 1);
 	
 		edit_dialog = microfeed_memory_allocate(EditDialog);
+		edit_dialog->just_created = just_created;
 		edit_dialog->dialog = gtk_dialog_new_with_buttons("Configure Microfeed Publisher", parent, 0, NULL);
+		edit_dialog->wizard_settings = microfeed_configuration_get_wizard_settings(configuration, publisher);
+		if (edit_dialog->wizard_settings) {
+			edit_dialog->wizard_mode = 1;
+			mode_button = gtk_button_new_with_label("Advanced");
+			gtk_dialog_add_action_widget(GTK_DIALOG(edit_dialog->dialog), mode_button, 1);
+		} else {
+			mode_button = gtk_button_new_with_label("Simple");
+			gtk_widget_set_sensitive(mode_button, FALSE);
+			gtk_dialog_add_action_widget(GTK_DIALOG(edit_dialog->dialog), mode_button, 1);
+		}
 		edit_dialog->edit_button = gtk_button_new_from_stock(GTK_STOCK_EDIT);
 		gtk_widget_set_sensitive(edit_dialog->edit_button, FALSE);
-		gtk_dialog_add_action_widget(GTK_DIALOG(edit_dialog->dialog), edit_dialog->edit_button, 1);
+		gtk_dialog_add_action_widget(GTK_DIALOG(edit_dialog->dialog), edit_dialog->edit_button, 2);
 #ifndef MAEMO_CHANGES
 		button = gtk_button_new_from_stock(GTK_STOCK_CLOSE);
 		gtk_dialog_add_action_widget(GTK_DIALOG(edit_dialog->dialog), button, GTK_RESPONSE_NONE);
@@ -224,7 +277,6 @@ void show_edit_dialog(MicrofeedSubscriber* subscriber, GtkWindow* parent, const
 	
 		edit_dialog->list_store = gtk_list_store_new(7, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_INT);		
 
-
 #ifdef MAEMO_CHANGES
 		touch_selector = hildon_touch_selector_new();
 		gtk_widget_set_size_request(touch_selector, -1, 250);
@@ -271,6 +323,17 @@ void show_edit_dialog(MicrofeedSubscriber* subscriber, GtkWindow* parent, const
 			
 			while ((response = gtk_dialog_run(GTK_DIALOG(edit_dialog->dialog))) != GTK_RESPONSE_DELETE_EVENT && response != GTK_RESPONSE_NONE) {
 				if (response == 1) {
+					mode_label = GTK_LABEL(gtk_bin_get_child(GTK_BIN(mode_button)));
+					if (edit_dialog->wizard_mode) {
+						edit_dialog->wizard_mode = 0;
+						gtk_label_set_text(mode_label, "Simple");
+						update_list(subscriber, publisher, edit_dialog);
+					} else {
+						edit_dialog->wizard_mode = 1;
+						gtk_label_set_text(mode_label, "Advanced");
+						update_list(subscriber, publisher, edit_dialog);
+					}
+				} else if (response == 2) {
 #ifdef MAEMO_CHANGES
 					if (hildon_touch_selector_get_selected(HILDON_TOUCH_SELECTOR(touch_selector), 0, &iter)) {
 						tree_model = GTK_TREE_MODEL(edit_dialog->list_store);
@@ -306,4 +369,6 @@ void show_edit_dialog(MicrofeedSubscriber* subscriber, GtkWindow* parent, const
 	
 		microfeed_subscriber_unsubscribe_feed(subscriber, publisher, MICROFEED_FEED_URI_SETTINGS, NULL, NULL);
 	}
+	
+	microfeed_configuration_free(configuration);
 }
