@@ -8,14 +8,13 @@
 
 int main(int argc, char** argv) {
 	const char* identifier = NULL;
-	MicrofeedConfiguration* configuration;
 	MicrofeedSubscriber* subscriber;
 	DBusError error;
 	DBusConnection* connection;
 
 	if (argc < 1 || argc > 2) {
 		fprintf(stderr, "Usage: %s [subscriber]\n", (argc > 0 ? argv[0] : "microfeed-configuration"));
-		
+
 		return 1;
 	} else if (argc == 2) {
 		identifier = argv[1];
@@ -26,8 +25,7 @@ int main(int argc, char** argv) {
 	connection = dbus_bus_get(DBUS_BUS_SESSION, &error);
 	dbus_connection_setup_with_g_main(connection, NULL);
 	
-	configuration = microfeed_configuration_new();
-	subscriber = microfeed_subscriber_new("org.microfeed.Utils.Configuration", "/org/microfeed/Utils/Configuration", configuration, connection);
+	subscriber = microfeed_subscriber_new("org.microfeed.Utils.Configuration", "/org/microfeed/Utils/Configuration", connection);
 
 	show_publishers_dialog(subscriber, NULL, identifier);
 	
