@@ -2,6 +2,7 @@
 #include "config.h"
 
 #include <microfeed-common/microfeedconfiguration.h>
+#include <microfeed-common/microfeedprotocol.h>
 #include <microfeed-common/microfeedmisc.h>
 #include <string.h>
 
@@ -90,7 +91,7 @@ static void update_list(MicrofeedConfiguration* configuration, GtkListStore* lis
 	const char** subscriptions;
 	const char** publishers;
 	GtkTreeIter iter;
-	const char* colon;
+	const char* separator;
 	char* publisher;
 	const char* name;
 	char* label;
@@ -105,9 +106,9 @@ static void update_list(MicrofeedConfiguration* configuration, GtkListStore* lis
 		subscriptions = NULL;
 	}
 	for (publishers = microfeed_configuration_get_publishers(configuration); publishers && *publishers; publishers++) {
-		if ((colon = strchr(*publishers, ':'))) {
-			publisher = g_strndup(*publishers, colon - *publishers);
-			name = microfeed_configuration_get_provider_name(configuration, colon + 1);
+		if ((separator = strchr(*publishers, MICROFEED_PUBLISHER_IDENTIFIER_SEPARATOR_CHAR))) {
+			publisher = g_strndup(*publishers, separator - *publishers);
+			name = microfeed_configuration_get_provider_name(configuration, separator + 1);
 			label = microfeed_util_string_concatenate(publisher, " (", name, ")", NULL);
 			g_free(publisher);
 		} else {
@@ -147,7 +148,7 @@ void show_publishers_dialog(MicrofeedSubscriber* subscriber, GtkWindow* parent,
 	int response;
 	char* publisher;
 
-	configuration = microfeed_subscriber_get_configuration(subscriber);
+	configuration = microfeed_configuration_new();
 	
 	publishers_dialog = microfeed_memory_allocate(PublishersDialog);
 	publishers_dialog->dialog = gtk_dialog_new_with_buttons((identifier ? "Subscribe Microfeed Publishers" : "Configure Microfeed Publishers"), parent, 0, NULL);
@@ -220,8 +221,11 @@ void show_publishers_dialog(MicrofeedSubscriber* subscriber, GtkWindow* parent,
 	while ((response = gtk_dialog_run(GTK_DIALOG(publishers_dialog->dialog))) != GTK_RESPONSE_DELETE_EVENT && response != GTK_RESPONSE_CLOSE) {
 		if (response == 1) {
 			if ((publisher = show_new_dialog(subscriber, GTK_WINDOW(publishers_dialog->dialog)))) {
+				if (identifier) {
+					microfeed_configuration_add_subscription(configuration, identifier, publisher);
+				}
 				update_list(configuration, list_store, identifier);
-				show_edit_dialog(subscriber, GTK_WINDOW(publishers_dialog->dialog), publisher);	
+				show_edit_dialog(subscriber, GTK_WINDOW(publishers_dialog->dialog), publisher, 1);	
 				free(publisher);
 			}
 		} else if (response == 2) {
@@ -231,7 +235,7 @@ void show_publishers_dialog(MicrofeedSubscriber* subscriber, GtkWindow* parent,
 			if (gtk_tree_selection_get_selected(selection, NULL, &iter)) {
 #endif
 				gtk_tree_model_get_value(GTK_TREE_MODEL(list_store), &iter, 2, &value);
-				show_edit_dialog(subscriber, GTK_WINDOW(publishers_dialog->dialog), g_value_get_string(&value));
+				show_edit_dialog(subscriber, GTK_WINDOW(publishers_dialog->dialog), g_value_get_string(&value), 0);
 				g_value_unset(&value);
 			}
 		} else if (response == 3) {
@@ -265,5 +269,7 @@ void show_publishers_dialog(MicrofeedSubscriber* subscriber, GtkWindow* parent,
 			}
 		}
 	}
+	
 	gtk_widget_destroy(publishers_dialog->dialog);
+	microfeed_configuration_free(configuration);
 }
