@@ -17,7 +17,6 @@ static void error_occured(MicrofeedSubscriber* subscriber, const char* publisher
 
 static void feed_subscribed(MicrofeedSubscriber* subscriber, const char* publisher, const char* uri, const char* uid, const char* error_name, const char* error_message, void* user_data) {
 	MicrofeedMain* microfeed_main;
-	MicrofeedItem* item;
 
 	microfeed_main = (MicrofeedMain*)user_data;
 
@@ -48,10 +47,6 @@ static void feed_republishing_ended(MicrofeedSubscriber* subscriber, const char*
 	printf("Republishing ended: %s %s\n", publisher, uri);
 }
 
-static void feed_name_changed(MicrofeedSubscriber* subscriber, const char* publisher, const char* uri, const char* name, void* user_data) {
-	printf("Feed name changed: %s %s (%s)\n", publisher, uri, name);
-}
-
 static void item_added(MicrofeedSubscriber* subscriber, const char* publisher, const char* uri, MicrofeedItem* item, void* user_data) {
 	MicrofeedItemIterator* iterator;
 	const char* key;
@@ -129,7 +124,6 @@ static MicrofeedSubscriberCallbacks callbacks = {
 
 int main(int argc, char** argv) {
 	MicrofeedMain* microfeed_main;
-	MicrofeedConfiguration* configuration;
 	MicrofeedSubscriber* subscriber;
 	int i;
 	
@@ -142,8 +136,7 @@ int main(int argc, char** argv) {
 	}
 	
 	microfeed_main = microfeed_main_new();
-	configuration = microfeed_configuration_new();
-	subscriber = microfeed_subscriber_new("org.microfeed.Utils.Subscriber", "/org/microfeed/Utils/Subscriber", configuration, microfeed_main_get_dbus_connection(microfeed_main));
+	subscriber = microfeed_subscriber_new("org.microfeed.Utils.Subscriber", "/org/microfeed/Utils/Subscriber", microfeed_main_get_dbus_connection(microfeed_main));
 	if (argc == 2) {
 		microfeed_subscriber_subscribe_feed(subscriber, argv[1], MICROFEED_FEED_URI_OVERVIEW, &callbacks, feed_subscribed, microfeed_main);
 	} else {
